@@ -19,7 +19,7 @@ test_that("cure_dataframe_variable_names", {
   mod <- glm(y ~ LNAADT + nlanes, family = poisson)
 
   ## Calculate residuals
-  res <- residuals(mod, type = "working")
+  res <- residuals(mod, type = "response")
 
   ## Calculate CURE plot data
   cure_df <- calculate_cure_dataframe(AADT, res)
